==> totoui-0.3.0.tgz: package/lib/paginationItem.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; desc = parent = getter = undefined; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _minxinsClassNameMixin = require('./minxins/ClassNameMixin');

var _minxinsClassNameMixin2 = _interopRequireDefault(_minxinsClassNameMixin);

var PaginationItem = (function (_React$Component) {
    _inherits(PaginationItem, _React$Component);

    function PaginationItem(props) {
        _classCallCheck(this, PaginationItem);

        _get(Object.getPrototypeOf(PaginationItem.prototype), 'constructor', this).call(this, props);
        for (var v in _minxinsClassNameMixin2['default']) {
            this[v] = _minxinsClassNameMixin2['default'][v].bind(this);
        }
    }

    _createClass(PaginationItem, [{
        key: 'render',
        value: function render() {
            var Component = this.props.componentTag;
            var classSet = this.getClassSet(true);
            var props = this.props;

            // .am-pagination-prev
            classSet[this.prefixClass('prev')] = props.prev;

            // .am-pagination-next
            classSet[this.prefixClass('next')] = props.next;

            return _react2['default'].createElement(
                Component,
                _extends({}, this.props, {
                    className: (0, _classnames2['default'])(classSet, this.props.className) }),
                _react2['default'].createElement(
                    'a',
                    {
                        href: this.props.href,
                        title: this.props.title,
                        target: this.props.target,
                        ref: "anchor" },
                    this.props.children
                )
            );
        }
    }]);

    return PaginationItem;
})(_react2['default'].Component);

PaginationItem.displayName = "PaginationItem";

PaginationItem.propTypes = {
    active: _react2['default'].PropTypes.bool,
    disabled: _react2['default'].PropTypes.bool,
    prev: _react2['default'].PropTypes.bool,
    next: _react2['default'].PropTypes.bool,
    href: _react2['default'].PropTypes.string,
    componentTag: _react2['default'].PropTypes.node.isRequired
};

PaginationItem.defaultProps = {
    classPrefix: 'pagination',
    href: '#',
    componentTag: 'li'
};

module.exports = PaginationItem;

==> totoui-0.5.1.tgz: package/lib/paginationItem.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; desc = parent = undefined; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _mixinsClassNameMixin = require('./mixins/ClassNameMixin');

var _mixinsClassNameMixin2 = _interopRequireDefault(_mixinsClassNameMixin);

var PaginationItem = (function (_React$Component) {
    _inherits(PaginationItem, _React$Component);

    function PaginationItem(props) {
        _classCallCheck(this, PaginationItem);

        _get(Object.getPrototypeOf(PaginationItem.prototype), 'constructor', this).call(this, props);
        for (var v in _mixinsClassNameMixin2['default']) {
            this[v] = _mixinsClassNameMixin2['default'][v].bind(this);
        }
    }

    _createClass(PaginationItem, [{
        key: 'render',
        value: function render() {
            var Component = this.props.componentTag;
            var classSet = this.getClassSet(true);
            var props = this.props;

            // .am-pagination-prev
            classSet[this.prefixClass('prev')] = props.prev;

            // .am-pagination-next
            classSet[this.prefixClass('next')] = props.next;

            return _react2['default'].createElement(
                Component,
                _extends({}, this.props, {
                    className: (0, _classnames2['default'])(classSet, this.props.className) }),
                _react2['default'].createElement(
                    'a',
                    {
                        href: this.props.href,
                        title: this.props.title,
                        target: this.props.target,
                        ref: 'anchor' },
                    this.props.children
                )
            );
        }
    }]);

    return PaginationItem;
})(_react2['default'].Component);

PaginationItem.displayName = "PaginationItem";

PaginationItem.propTypes = {
    active: _react2['default'].PropTypes.bool,
    disabled: _react2['default'].PropTypes.bool,
    prev: _react2['default'].PropTypes.bool,
    next: _react2['default'].PropTypes.bool,
    href: _react2['default'].PropTypes.string,
    componentTag: _react2['default'].PropTypes.node.isRequired
};

PaginationItem.defaultProps = {
    classPrefix: 'pagination',
    href: '#',
    componentTag: 'li'
};

module.exports = PaginationItem;
